package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.DomainResolution;

/**
 * 域名解析Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface DomainResolutionMapper 
{
    /**
     * 查询域名解析
     * 
     * @param id 域名解析主键
     * @return 域名解析
     */
    public DomainResolution selectDomainResolutionById(Integer id);

    /**
     * 查询域名解析列表
     * 
     * @param domainResolution 域名解析
     * @return 域名解析集合
     */
    public List<DomainResolution> selectDomainResolutionList(DomainResolution domainResolution);

    /**
     * 新增域名解析
     * 
     * @param domainResolution 域名解析
     * @return 结果
     */
    public int insertDomainResolution(DomainResolution domainResolution);

    /**
     * 修改域名解析
     * 
     * @param domainResolution 域名解析
     * @return 结果
     */
    public int updateDomainResolution(DomainResolution domainResolution);

    /**
     * 删除域名解析
     * 
     * @param id 域名解析主键
     * @return 结果
     */
    public int deleteDomainResolutionById(Integer id);

    /**
     * 批量删除域名解析
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDomainResolutionByIds(Integer[] ids);
}
